#
# spec file for package axis
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           axis
Version:        1.4
Release:        309.4
Summary:        Apache implementation of the SOAP
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://axis.apache.org/axis/
Source0:        axis-src-1_4.tar.bz2
# svn export http://svn.apache.org/repos/asf/webservices/axis/branches/AXIS_1_4_FINAL/
# Build only
# cvs -d :pserver:anonymous@dev.eclipse.org:/cvsroot/tools export -r v1_1_0 org.eclipse.orbit/javax.xml.rpc/META-INF/MANIFEST.MF
# mv org.eclipse.orbit/javax.xml.rpc/META-INF/MANIFEST.MF xmlrpc-MANIFEST.MF
Source1:        xmlrpc-MANIFEST.MF
# cvs -d :pserver:anonymous@dev.eclipse.org:/cvsroot/tools export -r v1_4_0 org.eclipse.orbit/org.apache.axis/META-INF/MANIFEST.MF
# mv org.eclipse.orbit/org.apache.axis/META-INF/MANIFEST.MF axis-MANIFEST.MF
Source2:        axis-MANIFEST.MF
# cvs -d :pserver:anonymous@dev.eclipse.org:/cvsroot/tools export -r v1_3_0 org.eclipse.orbit/javax.xml.soap/META-INF/MANIFEST.MF
# mv org.eclipse.orbit/javax.xml.soap/META-INF/MANIFEST.MF saaj-MANIFEST.MF
Source3:        saaj-MANIFEST.MF
Source4:        https://repo1.maven.org/maven2/axis/axis/1.4/axis-1.4.pom
Source5:        https://repo1.maven.org/maven2/axis/axis-ant/1.4/axis-ant-1.4.pom
Source6:        https://repo1.maven.org/maven2/axis/axis-jaxrpc/1.4/axis-jaxrpc-1.4.pom
Source7:        https://repo1.maven.org/maven2/axis/axis-saaj/1.4/axis-saaj-1.4.pom
Patch0:         unimplemented-dom3-methods.patch
Patch1:         axis-1.4-gcc44_build.patch
Patch2:         axis-manifest.patch
Patch3:         axis-ant-build.patch
Patch4:         axis-encoding.patch
Patch5:         axis-compareto.patch
Patch6:         axis-enum.patch
# PATCH-FIX-UPSTREAM bsc#1103658 CVE-2018-8032 cross-site scripting (XSS) attack in the default servlet/services
Patch7:         axis-CVE-2018-8032.patch
Patch8:         axis-jdk11.patch
# PATCH-FIX-UPSTREAM bsc#1134598 CVE-2012-5784 CVE-2014-3596 missing connection hostname check against X.509 certificate name
Patch9:         axis-CVE-2014-3596.patch
Patch10:        unimplemented-saaj13-methods.patch
# PATCH-FIX-UPSTREAM bsc#1218605 CVE-2023-51441 SSRF when untrusted input is passed to the service admin HTTP API
Patch11:        axis-CVE-2023-51441.patch
BuildRequires:  ant
BuildRequires:  ant-jdepend
BuildRequires:  antlr
BuildRequires:  apache-commons-httpclient
BuildRequires:  apache-commons-logging
BuildRequires:  glassfish-activation-api
BuildRequires:  jakarta-commons-discovery
BuildRequires:  java-devel >= 1.8
BuildRequires:  javamail
BuildRequires:  javapackages-local >= 6
BuildRequires:  junit
BuildRequires:  reload4j
BuildRequires:  servletapi5
BuildRequires:  unzip
BuildRequires:  wsdl4j
BuildRequires:  xerces-j2
Requires:       apache-commons-httpclient
Requires:       apache-commons-logging
Requires:       glassfish-activation-api
Requires:       jakarta-commons-discovery
Requires:       java >= 1.8
Requires:       javamail
Requires:       jaxp_parser_impl
Requires:       reload4j
Requires:       wsdl4j
Obsoletes:      %{name}-javadoc
BuildArch:      noarch

%description
Apache Axis is an implementation of the SOAP ("Simple Object Access
Protocol") submission to W3C.

%package manual
Summary:        Manual for axis
Group:          Documentation/Other

%description manual
Manual for axis

%prep
%setup -q -n %{name}-1_4

%patch -P 0 -p1
%patch -P 1 -p1 -b gcc44-build
%patch -P 2
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 7 -p1
%patch -P 8 -p1
%patch -P 9 -p1
%patch -P 10 -p1
%patch -P 11 -p1

# Remove provided binaries
find . "(" -name "*.jar" -o -name "*.zip" -o -name "*.class" ")" -delete
rm -rf src/org/apache/axis/enum
rm -f src/org/apache/axis/providers/java/CORBAProvider.java
rm -f src/org/apache/axis/deployment/wsdd/providers/WSDDJavaCORBAProvider.java
rm -f src/org/apache/axis/providers/java/EJBProvider.java
rm -f src/org/apache/axis/deployment/wsdd/providers/WSDDJavaEJBProvider.java

cp %{SOURCE1} %{SOURCE2} %{SOURCE3} .

mkdir -p build/schema

%build
[ -z "$JAVA_HOME" ] && export JAVA_HOME=%{_jvmdir}/java
CLASSPATH=$(build-classpath wsdl4j commons-discovery \
    commons-httpclient3 commons-logging reload4j \
    glassfish-activation-api javamail servletapi5)
export CLASSPATH=$CLASSPATH:$(build-classpath oro junit jdepend jimi xml-security jsse httpunit jms castor 2>/dev/null)
export OPT_JAR_LIST="ant/ant-nodeps"
ant -Dcompile.ime=true \
    -Dwsdl4j.jar=$(build-classpath wsdl4j) \
    -Dcommons-discovery.jar=$(build-classpath commons-discovery) \
    -Dcommons-logging.jar=$(build-classpath commons-logging) \
    -Dcommons-httpclient.jar=$(build-classpath commons-httpclient3) \
    -Dlog4j-core.jar=$(build-classpath reload4j/reload4j) \
    -Dactivation.jar=$(build-classpath glassfish-activation-api) \
    -Dmailapi.jar=$(build-classpath javamail/mailapi) \
    -Dxerces.jar=$(build-classpath jaxp_parser_impl) \
    -Dservlet.jar=$(build-classpath servletapi5) \
    -Dregexp.jar=$(build-classpath oro 2>/dev/null) \
    -Djunit.jar=$(build-classpath junit 2>/dev/null) \
    -Djimi.jar=$(build-classpath jimi 2>/dev/null) \
    -Djsse.jar=$(build-classpath jsse/jsse 2>/dev/null) \
    -Dant.build.javac.source=8 -Dsource=8 \
    -Dant.build.javac.target=8 -Dtarget=8 \
    clean compile

%install
### Jar files
install -d -m 755 %{buildroot}%{_javadir}/%{name}
pushd build/lib
   install -m 644 axis.jar axis-ant.jar saaj.jar jaxrpc.jar \
           %{buildroot}%{_javadir}/%{name}
popd

# POMs
install -d -m 755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} %{SOURCE4} %{buildroot}%{_mavenpomdir}/JPP.%{name}.pom
%add_maven_depmap JPP.%{name}.pom %{name}/axis.jar
%{mvn_install_pom} %{SOURCE5} %{buildroot}%{_mavenpomdir}/JPP.%{name}-ant.pom
%add_maven_depmap JPP.%{name}-ant.pom %{name}/axis-ant.jar -a org.apache.axis:axis-ant
%{mvn_install_pom} %{SOURCE6} %{buildroot}%{_mavenpomdir}/JPP.%{name}-jaxrpc.pom
%add_maven_depmap JPP.%{name}-jaxrpc.pom %{name}/jaxrpc.jar -a org.apache.axis:%{name}-jaxrpc
%{mvn_install_pom} %{SOURCE7} %{buildroot}%{_mavenpomdir}/JPP.%{name}-saaj.pom
%add_maven_depmap JPP.%{name}-saaj.pom %{name}/saaj.jar -a org.apache.axis:%{name}-saaj

%files -f .mfiles
%license LICENSE
%doc README release-notes.html changelog.html

%files manual
%doc docs/*

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Feb  9 2024 Fridrich Strba <fstrba@suse.com>
- Clean the spec file and use javapackages-local >= 6
* Thu Feb  8 2024 Gus Kenion <gkenion@suse.com>
- Security fix [bsc#1218605, CVE-2023-51441] SSRF when untrusted
  input is passed to the service admin HTTP API
  * Added axis-CVE-2023-51441.patch
  - Update axis-jdk11.patch, remove references to files that are
  no longer present.
* Mon Mar 21 2022 Fridrich Strba <fstrba@suse.com>
- Depend on the glassfish-activation-api standalone in order to
  prevent missing APIs when running the ant task
* Fri Mar 18 2022 Fridrich Strba <fstrba@suse.com>
- Unify the dependency on glassfish-activation-api instead of jaf
  and gnu-jaf
- Added patch:
  * unimplemented-saaj13-methods.patch
    + on systems where the JavaEE modules exist, allow building
    against newer versions of APIs
* Tue Mar  1 2022 Fridrich Strba <fstrba@suse.com>
- Alias relevant artifacts to org.apache.axis
* Tue Feb 22 2022 Fridrich Strba <fstrba@suse.com>
- Do not build against the log4j12 packages, use the new reload4j
* Tue Oct  1 2019 Fridrich Strba <fstrba@suse.com>
- Build against the new compat package log4j12-mini
* Thu May  9 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Security fix [bsc#1134598, CVE-2012-5784, CVE-2014-3596]
  Missing connection hostname check against X.509 certificate name
  * Added axis-CVE-2014-3596.patch
* Mon Apr 15 2019 Jan Engelhardt <jengelh@inai.de>
- Replace find -exec rm by just -delete
* Tue Jan 22 2019 Fridrich Strba <fstrba@suse.com>
- Require for build the generic javamail instead of classpathx-mail
* Fri Sep  7 2018 pmonrealgonzalez@suse.com
- Security fix: [bsc#1103658, CVE-2018-8032]
  * Apache Axis 1.x up to and including 1.4 is vulnerable to a
    cross-site scripting (XSS) attack in the default
    servlet/services.
  * Added axis-CVE-2018-8032.patch
* Tue Jul 10 2018 fstrba@suse.com
- Added patch:
  * axis-jdk11.patch
    + Fix build with jdk11
    + Don't build providers that are using APIs and classes removed
    in jdk11
* Tue May 15 2018 fstrba@suse.com
- Build with source and target 8 to prepare for a possible removal
  of 1.6 compatibility
* Thu Oct  5 2017 fstrba@suse.com
- Remove the 3 deprecated classes from package org.apache.axis.enum
  * allows building with java source and target >= 1.5
- Added patches:
  * axis-encoding.patch
    + Specify file encoding ISO-8859-1 in order to avoid compiler
    errors with characters unmappable in ASCII
  * axis-enum.patch
    + Rename variable enum to emun to avoid clash with reserved
    word in java5+
  * axis-compareto.patch
    + Rewrite the UnsignedInt::compareTo and
    UnsignedLong::compareTo to check first that the Object we
    compare with is instance of the respective class
* Thu Sep 14 2017 fstrba@suse.com
- BuildRequires: java-devel >= 1.6
- BuildConflicts: java-devel >= 1.9
  * Allow building with wider range of java compilers
- Clean spec file
* Sun Sep 10 2017 fstrba@suse.com
- Requires for build java-devel = 1.8.0 since it is the last
  version able to build with source and target levels 1.3
* Fri May 19 2017 tchvatal@suse.com
- Fix build with new javapackages-tools
* Wed May 17 2017 tchvatal@suse.com
- Disable javadoc
- Fix build with new ant 1.9.8+
  * axis-ant-build.patch
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Fri Jun 27 2014 tchvatal@suse.com
- Fix back javadoc
* Fri Jun 27 2014 tchvatal@suse.com
- Depend on proper apache pkgs
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Tue Feb 28 2012 mvyskocil@suse.cz
- strip the jakarta- from classpath to be ready for jakarta->apache-commons
  renaming
- added some pms and manifest files
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Fri Mar 11 2011 mvyskocil@suse.cz
- build using openjdk, use ant.build.javac.target and source 1.4
  to prevent javadoc fail, clean up BuildRequires
* Thu May 21 2009 mvyskocil@suse.cz
- fixed build with new gcj44
* Thu Jul 31 2008 mvyskocil@suse.cz
- replace gnu-javamail dependency to classpathx-mail [bnc#411839]
  - the classpathx-foo is consistent with jpackage.org project
* Wed Jul 16 2008 coolo@suse.de
- avoid another build cycle
* Tue Apr 22 2008 mvyskocil@suse.cz
- fixed build with new gcj (memory consupmtion limit)
* Thu Jan 17 2008 skh@suse.de
- remove glibj from build-classpath call as we don't have classpath
  packages
* Wed May  2 2007 dbornkessel@suse.de
- added unzip to BuildRequires
* Thu Jan  5 2006 dbornkessel@suse.de
- Current version 1.2.3 from JPackage.org
